/**
 * Gulpfile.
 *
 * Implements:
 *   1. CSS:
 *    a. Sass to CSS conversion
 *    b. Error catching
 *    c. Autoprefixing
 *    d. CSS nano
 *    e. Rename
 *    f. Sourcemaps
 *   2. Minifies JS.
 *   3. Images: Minifies all images.
 *   4. Generate .pot file.
 *   5. Watches files for changes in Sass.
 *   6. Create zip for production.
 */

const { src, dest, watch, series } = require('gulp');

const imagemin     = require('gulp-imagemin');
const rename       = require('gulp-rename');
const sass         = require('gulp-sass');
const postcss      = require('gulp-postcss');
const autoprefixer = require('autoprefixer');
const cssnano      = require('cssnano');
const wpPot        = require('gulp-wp-pot');
sass.compiler      = require('node-sass');
const concat       = require('gulp-concat');
var uglify         = require('gulp-uglify');
var environments   = require('gulp-environments');
const zip          = require('gulp-zip');

var development = environments.development;
var production = environments.production;

var paths = {
  style: {
    src: [
      'sass/**/*.scss',
      '!sass/responsive.scss',
      '!sass/woocommerce.scss'
    ],
    dest: './'
  },
  js: {
    src: [
      'includes/admin/libs/mts-options/src/options.js',
      'includes/admin/libs/mts-options/fields/**/*.js',
      '!includes/admin/libs/mts-options/fields/color/wp-color-picker-alpha.min.js'
    ],
    dest: 'includes/admin/libs/mts-options/js'
  },
  responsive: {
    src: 'sass/responsive.scss',
    dest: 'css'
  },
  woocommerce: {
    src: 'sass/woocommerce.scss',
    dest: 'css'
  },
  options: {
    src: 'includes/admin/libs/mts-options/sass/options.scss',
    dest: 'includes/admin/libs/mts-options/css'
  },
  aristo: {
    src: 'includes/admin/libs/mts-options/sass/aristo.scss',
    dest: 'includes/admin/libs/mts-options/css'
  },
  images: {
    src: 'images/**',
    dest: 'minified'
  },
  pot: {
    src: '**/*.php',
    dest: 'languages/chronicle.pot'
  },
  bundle: {
    files: [
      '**/*',
      '!**/*.map',
      '!node_modules/**',
      '!gulpfile.js',
      '!package-lock.json',
      '!.babelrc',
      '!.eslintrc',
      '!.gitattributes',
      '!.gitignore',
      '!.phpcs.xml.dist',
      '!composer.json',
      '!composer.lock'
    ],
    dest: '../'
  }
};

/**
 * Converting Sass into css
 * Applying autoprefixer
 * Creatings sourcemaps
 */
function style() {

  // Main Style
  return src( paths.style.src, { sourcemaps: development() ? true : false } )
    .pipe(sass())
    .on('error', sass.logError)
    // Use postcss with autoprefixer and compress the compiled file using cssnano
    .pipe(postcss([autoprefixer(), cssnano()]))
    .pipe( rename( { basename: 'style' } ) )
    .pipe( dest( paths.style.dest, { sourcemaps: '.' } ) );

}

function responsivestyle() {

  // Responsive
  return src( paths.responsive.src, { sourcemaps: development() ? true : false } )
    .pipe(sass())
    .on('error', sass.logError)
    // Use postcss with autoprefixer and compress the compiled file using cssnano
    .pipe(postcss([autoprefixer(), cssnano()]))
    .pipe( rename( { prefix: 'chronicle-' } ) )
    .pipe( dest( paths.responsive.dest, { sourcemaps: '.' } ) );
}

function woocommercestyle() {

  // WooCommerce
  return src( paths.woocommerce.src, { sourcemaps: development() ? true : false } )
    .pipe(sass())
    .on('error', sass.logError)
    // Use postcss with autoprefixer and compress the compiled file using cssnano
    .pipe(postcss([autoprefixer(), cssnano()]))
    .pipe( rename( { prefix: 'chronicle-' } ) )
    .pipe( dest( paths.woocommerce.dest, { sourcemaps: '.' } ) );

}

function optionstyle() {

  // Options CSS
  return src( paths.options.src, { sourcemaps: development() ? true : false } )
    .pipe(sass())
    .on('error', sass.logError)
    // Use postcss with autoprefixer and compress the compiled file using cssnano
    .pipe(postcss([autoprefixer(), cssnano()]))
    .pipe( dest( paths.options.dest, { sourcemaps: '.' } ) );

}

function aristostyle() {

  // Options CSS
  return src(paths.aristo.src, { sourcemaps: development() ? true : false })
    .pipe(sass())
    .on('error', sass.logError)
    // Use postcss with autoprefixer and compress the compiled file using cssnano
    .pipe(postcss([autoprefixer(), cssnano()]))
    .pipe(dest(paths.aristo.dest, { sourcemaps: '.' }));

}

function js() {
  return src( paths.js.src )
    .pipe(concat('chronicle-options.js'))
    .pipe(uglify())
    .pipe( dest( paths.js.dest ) );
}

// Optimizing images
function optimize() {

  return src( paths.images.src )
    .pipe(imagemin())
    .pipe(dest( paths.images.dest ));

}

// Generate .pot file
function pot() {

  return src( paths.pot.src )
    .pipe(wpPot( {
      domain: 'chronicle',
      package: 'chronicle'
    } ))
    .pipe(dest( paths.pot.dest ));

}
function bundle() {
  return src( paths.bundle.files )
  .pipe( zip('mts_chronicle.zip') )
  .pipe(dest( paths.bundle.dest ));
}

var build = series(style, responsivestyle, woocommercestyle, optionstyle, aristostyle, bundle);

function watch_files() {
  watch( paths.style.src, style );
  watch( paths.responsive.src, responsivestyle );
  watch( paths.woocommerce.src, woocommercestyle );
  watch( paths.options.src, optionstyle );
  watch( paths.aristo.src, aristostyle );
  watch( paths.js.src, js );
}

exports.style = style;
exports.responsivestyle = responsivestyle;
exports.woocommercestyle = woocommercestyle;
exports.optionstyle = optionstyle;
exports.aristostyle = aristostyle;
exports.js = js;
exports.optimize = optimize;
exports.pot = pot;
exports.build = build;
exports.watch = watch_files;
