<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Chronicle
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function chronicle_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function chronicle_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function chronicle_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function chronicle_merge_value( &$css, $values ) {
	foreach ( $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function chronicle_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = chronicle()->get_page_id();

	// Site Background.
	$css['global']['html body, #sidebar .widget h3 span'] = Chronicle_Sanitize::background( chronicle_get_settings( 'theme_background' ) );

	// Header Background.

	// Logo Font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'chronicle_logo' ) ) );
	// Primary Navigation font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'primary_navigation_font' ) ) );
	// Content Font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'content_font' ) ) );
	// Pagination.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'pagination_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'loadmore_font' ) ) );
	// Single post title font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'single_title_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'pages_title_font' ) ) );
	// Single Page titles font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'single_page_titles_font' ) ) );
	// Single subscribe box.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'single_subscribe_title_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'single_subscribe_text_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'single_subscribe_input_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'single_subscribe_submit_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'authorbox_title_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'authorbox_author_name_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'authorbox_text_font' ) ) );
	// Sidebar widget title font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'sidebar_title_font' ) ) );
	// Sidebar widget font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'sidebar_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'sidebar_links_widgets' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'sidebar_post_title' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'sidebar_large_post_title' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'sidebar_postinfo_font' ) ) );
	// Footer widget title font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'top_footer_title_font' ) ) );
	// Footer widget font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'top_footer_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'footer_links_widgets' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'top_footer_post_title' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'footer_large_post_title' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'top_footer_meta_font' ) ) );
	// Copyrights section font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'copyrights_font' ) ) );
	// Fields font.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'fields_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'buttons_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'blockquote_font' ) ) );
	// H1 title in the content.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Chronicle_Sanitize::background( chronicle_get_settings( 'mts_footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Chronicle_Sanitize::background( chronicle_get_settings( 'mts_copyrights_background' ) );
	// Sidebar Subscribe Widget
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'subscribe_widget_title_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'sidebar_fields_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'subscribe_widget_text_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'subscribe_widget_submit_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'subscribe_widget_small_text_font' ) ) );
	// Footer Subscribe Widget
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'footer_subscribe_widget_title_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'footer_fields_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'footer_subscribe_widget_text_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'footer_subscribe_widget_submit_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'footer_subscribe_widget_small_text_font' ) ) );

	chronicle_dynamic_css_skin( $css );
	chronicle_sidebar_position( $css );
	chronicle_header( $css );
	chronicle_sidebar_styling( $css );
	chronicle_post_layouts( $css );
	chronicle_post_pagination( $css );
	chronicle_footer( $css );
	chronicle_copyrights( $css );
	chronicle_single( $css );
	chronicle_single_social_buttons( $css );
	chronicle_archive_post( $css );
	chronicle_misc_css( $css );

	return apply_filters( 'chronicle_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme   = Chronicle_Sanitize::color( chronicle_get_settings( 'primary_color_scheme' ) );
	$secondary_color_scheme = Chronicle_Sanitize::color( chronicle_get_settings( 'secondary_color_scheme' ) );

	// Text Color.
	$elements = array(
		'a',
		'body a:hover',
		'.sidebar .widget li a:hover',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#tabber .inside li a:hover',
		'.fn a',
		'.related-posts .title a:hover',
		'blockquote:after',
		'article ul li::before',
		'blockquote::before',
		'.postauthor h5 a:hover',
		'.related-readmore a',
		'.widget .sbutton:hover',
		'.shareit-circular.standard .share-text',
		'.f-widget .widget li.horizontal-small .post-title a:hover',
		'.f-widget .aboutme-widget .aboutme-social a:hover',
		'.aboutme-widget .aboutme-social a:hover',
		'#copyright-note a:hover',
		'.sbutton',
		'.total-posts-number',
		'.tags a:hover',
		'.tagcloud a:hover',
		'.woocommerce .woocommerce-breadcrumb a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover',
	);
	$css['global'][ chronicle_implode( $elements ) ]['color'] = $primary_color_scheme;

	// Primary Text Color Important.
	$elements = array(
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.review-total-only.small-thumb .review-result-wrapper i',
		'.widget.widget_categories li a:hover',
		'.widget.widget_archive li a:hover',
		'.widget.widget_pages li a:hover',
		'.widget.widget_meta li a:hover',
		'.widget.widget_recent_comments li a:hover',
		'.widget.widget_recent_entries li a:hover',
		'.widget.widget_rss li a:hover',
		'.widget.widget_nav_menu li a:hover',
		'.post-title a:hover',
		'.entry-title a:hover',
		'.shareit-circular.standard .fa:hover',
		'.latestPost .title a:hover',
		'.post-info a:hover',
		'.tagcloud a:hover',
		'.sidebar .widget li.horizontal-small .post-title a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover',
		'.pagination .nav-previous a:hover',
		'.pagination .nav-next a:hover',
		'.widget .wpt-pagination a:hover',
		'.widget .wp-review-tab-pagination a:hover',
	);
	$css['global'][ chronicle_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Secondary Color.
	$elements = array(
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.widget .wpt_widget_content .tab_title a',
		'.widget .wp_review_tab_widget_content .tab_title a',
	);
	$css['global'][ chronicle_implode( $elements ) ]['color'] = $secondary_color_scheme;

	// social svg hover color.
	$css['global']['.shareit-circular.standard svg:hover']['fill'] = $primary_color_scheme;

	// Secondary Background Color.
	$elements = array(
		'.widget .wpt_widget_content .tab_title.selected a',
		'.widget .wp_review_tab_widget_content .tab_title.selected a',
		'.owl-prev:hover, .owl-next:hover',
		'#wpmm-megamenu .review-total-only',
		'.widget #wp-subscribe input.submit:hover',
		'.single-subscribe .widget #wp-subscribe input.submit:hover',
		'.button:hover',
		'.prev-next .prev a:hover',
		'.prev-next .next a:hover',
		'#commentform input#submit:hover',
		'#mtscontact_submit:hover',
		'.woocommerce a.button:hover',
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce-page #respond input#submit:hover',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'.woocommerce a.button:hover',
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce-page #respond input#submit:hover',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt:hover',
		'.woocommerce button.button.alt:hover',
		'.woocommerce input.button.alt:hover',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit:hover',
		'.woocommerce .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce div.product form.cart .button:hover',
		'.instagram-button a:hover',
		'.woocommerce div.product form.cart .button:hover',
		'.woocommerce-page div.product form.cart .button:hover',
		'.woocommerce .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce #payment #place_order:hover',
		'.woocommerce-page #payment #place_order:hover',
		'#site-footer .widget #wp-subscribe input.submit:hover',
	);
	$css['global'][ chronicle_implode( $elements ) ]['background-color'] = $secondary_color_scheme;

	// Primary Background Color.
	$elements = array(
		'.owl-prev, .owl-next',
		'.prev-next .prev a',
		'.prev-next .next a',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce span.onsale',
		'.woocommerce .bypostauthor:after',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.instagram-button a',
		'.woocommerce a.button, .woocommerce button.button',
		'.woocommerce input.button, .woocommerce #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce-page a.button, .woocommerce-page button.button',
		'.woocommerce-page input.button',
		'.woocommerce-page #respond input#submit',
		'.woocommerce-page #content input.button',
		'.woocommerce-page .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce div.product form.cart .button',
		'.woocommerce-page div.product form.cart .button',
		'.woocommerce .widget.widget_product_search button[type="submit"]',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]',
		'.woocommerce a.checkout-button.button',
		'.woocommerce #payment #place_order',
		'.woocommerce-page #payment #place_order',
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.button',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
	);
	$css['global'][ chronicle_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	$css['@media screen and (max-width: 865px)']['.navigation.mobile-menu-wrapper']['background-color'] = $secondary_color_scheme;

	// Background Color Important.
	$elements = array(
		'.shareit-circular.circular-standard .social-icon:hover',
	);
	$css['global'][ chronicle_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = array(
		'.page-numbers.current',
		'.pagination a:hover',
		'.widget #wp-subscribe input.email-field:focus',
		'.widget #wp-subscribe input.name-field:focus',
	);
	$css['global'][ chronicle_implode( $elements ) ]['border-color'] = $primary_color_scheme;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = chronicle_get_settings( 'theme_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== chronicle_get_settings( 'mts_social_button_position' ) && 'floating' === chronicle_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = array(
				'.sclayout .shareit.shareit-default.floating',
				'.sclayout .shareit.standard.floating',
				'.sclayout .shareit.shareit-circular.floating',
			);

			$css['global'][ chronicle_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ chronicle_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ chronicle_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ chronicle_implode( $shareit_class ) ]['margin-right'] = chronicle_px2rem( '100px' );
		}
	}
	$sidebar_meta_info_class = array(
		'.sidebar .post-info > span:after',
		'.sidebar .post-info > span.thecategory a:last-child:after',
	);
	$sidebar_meta_info_font  = chronicle_get_settings( 'sidebar_postinfo_font' );
	$css['global'][ chronicle_implode( $sidebar_meta_info_class ) ]['background-color'] = Chronicle_Sanitize::color( $sidebar_meta_info_font['color'] );
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_header( &$css ) {
	// Header.
	$header_bg_class = array(
		'#header',
		'#site-header .searchbox .searchbox-input',
		'#site-header .searchbox.searchbox-open .searchbox-icon',
	);
	$header_class    = array(
		'#header',
	);
	//background
	$css['global'][ chronicle_implode( $header_bg_class ) ] = Chronicle_Sanitize::background( chronicle_get_settings( 'header_background' ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $header_class ) ], Chronicle_Sanitize::margin( chronicle_get_settings( 'header_margin' ) ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $header_class ) ], Chronicle_Sanitize::padding( chronicle_get_settings( 'header_padding' ) ) );

	// Header Border.
	$header_border = Chronicle_Sanitize::border( chronicle_get_settings( 'header_border' ) );
	$css['global'][ chronicle_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	$css['global']['#primary-navigation .navigation ul ul a']['color']            = Chronicle_Sanitize::color( chronicle_get_settings( 'main_navigation_dropdown_color' ) );
	$css['global']['#primary-navigation .navigation ul ul']['background']         = Chronicle_Sanitize::color( chronicle_get_settings( 'main_navigation_dropdown_background' ) );
	$css['global']['#primary-navigation .navigation ul li:hover > a']['color']    = Chronicle_Sanitize::color( chronicle_get_settings( 'main_navigation_hover_color' ) );
	$css['global']['#primary-navigation .navigation ul ul li:hover > a']['color'] = Chronicle_Sanitize::color( chronicle_get_settings( 'main_navigation_dropdown_hover_color' ) );
	// Nav Padding.
	chronicle_merge_value( $css['global']['#primary-navigation'], Chronicle_Sanitize::padding( chronicle_get_settings( 'header_nav_padding' ) ) );
	// Social icons.
	$header_icons = chronicle_get_settings( 'header_social_icons' );
	if ( ! empty( $header_icons ) && is_array( $header_icons ) ) :
		foreach ( $header_icons as $header_icon ) :
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['background-color']            = Chronicle_Sanitize::color( $header_icon['header_icon_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['background-color'] = Chronicle_Sanitize::color( $header_icon['header_icon_hover_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['color']                       = Chronicle_Sanitize::color( $header_icon['header_icon_color'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['color']            = Chronicle_Sanitize::color( $header_icon['header_icon_hover_color'] );
			chronicle_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Chronicle_Sanitize::margin( $header_icon['header_icon_margin'] ) );
			chronicle_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Chronicle_Sanitize::padding( $header_icon['header_icon_padding'] ) );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['border-radius'] = Chronicle_Sanitize::size( $header_icon['header_icon_border_radius'] . 'px' );
		endforeach;
	endif;

	// Header Ad.
	chronicle_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Chronicle_Sanitize::margin( chronicle_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Chronicle_Sanitize::color( chronicle_get_settings( 'navigation_ad_background' ) );

	// Header Search
	$header_padding = Chronicle_Sanitize::padding( chronicle_get_settings( 'header_padding' ) );
	$top            = $header_padding['padding-bottom'];
	//Top Position
	$css['global']['.header-search']['top'] = 'calc( 104% - ' . $top . ' )';
	//Header Layout2 Search
	$css['global']['.header-layout2 .header-search']['margin-top'] = '-' . $top;
	// Search button settings
		$css['global']['.header-search']['background']              = Chronicle_Sanitize::color( chronicle_get_settings( 'header_search_bg' ) );
		$css['global']['.header-search button']['background']       = Chronicle_Sanitize::color( chronicle_get_settings( 'header_search_button' ) );
		$css['global']['.header-search button:hover']['background'] = Chronicle_Sanitize::color( chronicle_get_settings( 'header_search_button_bg' ) );

	//Layout 2 Header Nav Sections
	$header_layout_nav_class = array(
		'.header-layout2-bottom',
	);
	chronicle_merge_value( $css['global'][ chronicle_implode( $header_layout_nav_class ) ], Chronicle_Sanitize::background( chronicle_get_settings( 'header_layout2_nav_background' ) ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $header_layout_nav_class ) ], Chronicle_Sanitize::padding( chronicle_get_settings( 'header_layout2_nav_padding' ) ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $header_layout_nav_class ) ], Chronicle_Sanitize::margin( chronicle_get_settings( 'header_layout2_nav_margin' ) ) );
	$header_layout2_nav_border = Chronicle_Sanitize::border( chronicle_get_settings( 'header_layout2_nav_border' ) );
	$css['global'][ chronicle_implode( $header_layout_nav_class ) ][ $header_layout2_nav_border ['direction'] ] = $header_layout2_nav_border ['value'];

	// Floating Navigation Responsive
	if ( ! chronicle_get_settings( 'sticky_responsive_nav' ) ) :
		$css['@media screen and (max-width: 865px)']['#catcher']['height'] = '0px!important';
		// position relative!important
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active, .admin-bar .sticky-navigation-active']['top']  = '0px!important';
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active, #header.sticky-navigation-active']['position'] = 'relative!important';
	endif;
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.shareit.floating'] = Chronicle_Sanitize::background( chronicle_get_settings( 'social_styling_background' ) );
	chronicle_merge_value( $css['global']['.shareit.floating'], Chronicle_Sanitize::margin( chronicle_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Chronicle_Sanitize::border( chronicle_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = chronicle_get_settings( 'social_button_layout' );
	$social_button_position = chronicle_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_sidebar_styling( &$css ) {

	// Sidebar.
	$sidebar_widget = '.sidebar .widget';
	chronicle_merge_value( $css['global'][ $sidebar_widget ], Chronicle_Sanitize::background( chronicle_get_settings( 'sidebar_styling_background' ) ) );
	chronicle_merge_value( $css['global'][ $sidebar_widget ], Chronicle_Sanitize::margin( chronicle_get_settings( 'sidebar_styling_margin' ) ) );
	chronicle_merge_value( $css['global'][ $sidebar_widget ], Chronicle_Sanitize::padding( chronicle_get_settings( 'sidebar_styling_padding' ) ) );

	// Sidebar border.
	$sidebar_border = Chronicle_Sanitize::border( chronicle_get_settings( 'sidebar_styling_border' ) );
	$css['global'][ $sidebar_widget ][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3';
	$css['global'][ $sidebar_title ] = Chronicle_Sanitize::background( chronicle_get_settings( 'sidebar_title_styling_background' ) );
	chronicle_merge_value( $css['global'][ $sidebar_title ], Chronicle_Sanitize::padding( chronicle_get_settings( 'sidebar_title_styling_padding' ) ) );
	chronicle_merge_value( $css['global'][ $sidebar_title ], Chronicle_Sanitize::margin( chronicle_get_settings( 'sidebar_title_styling_margin' ) ) );

	// Sidebar Title border.
	$sidebar_title_border = Chronicle_Sanitize::border( chronicle_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];

	// Subscribe Box.
	$css['global']['.widget.wp_subscribe'] = Chronicle_Sanitize::background( chronicle_get_settings( 'subscribe_widget_background' ) );
	chronicle_merge_value( $css['global']['.widget.wp_subscribe'], Chronicle_Sanitize::padding( chronicle_get_settings( 'subscribe_widget_padding' ) ) );
	$subscribe_border = Chronicle_Sanitize::border( chronicle_get_settings( 'subscribe_widget_border' ) );
	$css['global']['.widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];
	// Subscribe Box Submit button.
	$css['global']['.widget #wp-subscribe input.submit']['background'] = Chronicle_Sanitize::color( chronicle_get_settings( 'subscribe_widget_submit_backgroud' ) );

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_post_layouts( &$css ) {

	// Post Layouts.
	$features = chronicle_get_settings( 'featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id;
		chronicle_merge_value( $css['global'][ $title_class ], Chronicle_Sanitize::margin( chronicle_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
		chronicle_merge_value( $css['global'][ $title_class ], Chronicle_Sanitize::padding( chronicle_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Chronicle_Sanitize::border( chronicle_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Chronicle_Sanitize::border( chronicle_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		/**
		 * Post Hover Settings
		 */
		chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'view_more_font_' . $unique_id ) ) );
		$css['global'][ '.layout-' . $unique_id . ' .view-more' ]['background-color']         = Chronicle_Sanitize::color( chronicle_get_settings( 'view_more_bg_' . $unique_id ) );
		$css['global'][ '.layout-' . $unique_id . ' .post-hover:before' ]['background-color'] = Chronicle_Sanitize::color( chronicle_get_settings( 'post_overlay_' . $unique_id ) );
		/**
		 * Meta info
		 */
		chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'meta_info_font_' . $unique_id ) ) );
		chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'post_title_font_' . $unique_id ) ) );
		chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'post_excerpt_font_' . $unique_id ) ) );

		$css['global'][ $post_class ] = Chronicle_Sanitize::background( chronicle_get_settings( 'post_background_' . $unique_id ) );
		// All Posts Margin and Padding.
		chronicle_merge_value( $css['global'][ $post_class ], Chronicle_Sanitize::margin( chronicle_get_settings( 'post_margin_' . $unique_id ) ) );
		chronicle_merge_value( $css['global'][ $post_class ], Chronicle_Sanitize::padding( chronicle_get_settings( 'post_padding_' . $unique_id ) ) );

		//Post Alignment
		$post_alignment       = chronicle_get_settings( 'post_alignment_' . $unique_id );
		$post_alignment_class = array(
			'.layout-' . $unique_id . ' .latestPost',
		);
		if ( 'center' === $post_alignment ) :
			$css['global'][ chronicle_implode( $post_alignment_class ) ]['text-align'] = 'center';
		endif;
		if ( 'right' === $post_alignment ) :
			$css['global'][ chronicle_implode( $post_alignment_class ) ]['text-align'] = 'right';
		endif;

		// Post Meta Info Divider
		$post_meta_info_class = array(
			'.layout-' . $unique_id . ' .latestPost .post-info > span:after',
			'.layout-' . $unique_id . ' .latestPost .post-info > span.thecategory a:last-child:after',
		);
		$post_meta_info_font  = chronicle_get_settings( 'meta_info_font_' . $unique_id );
		$css['global'][ chronicle_implode( $post_meta_info_class ) ]['background-color'] = Chronicle_Sanitize::color( $post_meta_info_font['color'] );

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
		'.single .pagination > .current .currenttext',
		'#mobile-menu-wrapper ul li a:hover',
		'#load-posts a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'#load-posts a',
		'.pagination .page-numbers.dots',
		'.page-numbers.current',
	);
	if ( '2' !== chronicle_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ chronicle_implode( $pagination_class ) ]['background-color']        = Chronicle_Sanitize::color( chronicle_get_settings( 'mts_pagenavigation_bgcolor' ) );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['background-color'] = Chronicle_Sanitize::color( chronicle_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global'][ chronicle_implode( $pagination_class ) ]['color']                   = Chronicle_Sanitize::color( chronicle_get_settings( 'mts_pagenavigation_color' ) );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['color']            = Chronicle_Sanitize::color( chronicle_get_settings( 'mts_pagenavigation_hover_color' ) );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['border-color']     = Chronicle_Sanitize::color( chronicle_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		chronicle_merge_value( $css['global'][ chronicle_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Chronicle_Sanitize::margin( chronicle_get_settings( 'mts_pagenavigation_margin' ) ) );
		chronicle_merge_value( $css['global'][ chronicle_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Chronicle_Sanitize::padding( chronicle_get_settings( 'mts_pagenavigation_padding' ) ) );
		$css['global'][ chronicle_implode( $pagination_class ) ]['min-width']          = Chronicle_Sanitize::size( chronicle_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['min-width']   = Chronicle_Sanitize::size( chronicle_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ chronicle_implode( $pagination_class ) ]['line-height']        = Chronicle_Sanitize::size( chronicle_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['line-height'] = Chronicle_Sanitize::size( chronicle_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		// Pagination border.
		$pagination_border = Chronicle_Sanitize::border( chronicle_get_settings( 'pagenavigation_border' ) );
		$css['global'][ chronicle_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];
		$pagination_hover_border = Chronicle_Sanitize::border( chronicle_get_settings( 'pagenavigation_hover_border' ) );
		$css['global'][ chronicle_implode( $pagination_class_active ) ][ $pagination_hover_border ['direction'] ] = $pagination_hover_border ['value'];
		$css['global'][ chronicle_implode( $pagination_class ) ]['border-radius']                                 = Chronicle_Sanitize::size( chronicle_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['border-radius']                          = Chronicle_Sanitize::size( chronicle_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
	} else {
		$css['global'][ chronicle_implode( $pagination_class ) ]['background-color']        = Chronicle_Sanitize::color( chronicle_get_settings( 'load_more_bgcolor' ) );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['background-color'] = Chronicle_Sanitize::color( chronicle_get_settings( 'load_more_hover_bgcolor' ) );
		$css['global'][ chronicle_implode( $pagination_class ) ]['color']                   = Chronicle_Sanitize::color( chronicle_get_settings( 'load_more_color' ) );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['color']            = Chronicle_Sanitize::color( chronicle_get_settings( 'load_more_hover_color' ) );
		chronicle_merge_value( $css['global'][ chronicle_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Chronicle_Sanitize::padding( chronicle_get_settings( 'load_more_padding' ) ) );
		chronicle_merge_value( $css['global'][ chronicle_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Chronicle_Sanitize::margin( chronicle_get_settings( 'load_more_margin' ) ) );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['border-color'] = Chronicle_Sanitize::color( chronicle_get_settings( 'load_more_hover_bgcolor' ) );
		// Load More border.
		$load_more_border = Chronicle_Sanitize::border( chronicle_get_settings( 'load_more_border' ) );
		$css['global'][ chronicle_implode( $pagination_class ) ][ $load_more_border ['direction'] ] = $load_more_border ['value'];
		$css['global'][ chronicle_implode( $pagination_class ) ]['border-radius']                   = Chronicle_Sanitize::size( chronicle_get_settings( 'load_more_border_radius' ) . 'px' );
		$css['global'][ chronicle_implode( $pagination_class_active ) ]['border-radius']            = Chronicle_Sanitize::size( chronicle_get_settings( 'load_more_border_radius' ) . 'px' );
	}

	// Load more Alignment.
	$load_more_align = chronicle_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_single( &$css ) {

	// Single, Page and 404 Page Background.
	$page_classes = array(
		'.single_post',
		'.page .article',
		'.error404 .article',
	);

	$css['global'][ chronicle_implode( $page_classes ) ] = Chronicle_Sanitize::background( chronicle_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	chronicle_merge_value( $css['global'][ chronicle_implode( $page_classes ) ], Chronicle_Sanitize::margin( chronicle_get_settings( 'mts_single_styling_margin' ) ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $page_classes ) ], Chronicle_Sanitize::padding( chronicle_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Chronicle_Sanitize::border( chronicle_get_settings( 'single_styling_border' ) );
	$css['global'][ chronicle_implode( $page_classes ) ][ $single_border ['direction'] ] = $single_border ['value'];

	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'mts_single_meta_info_font' ) ) );
	$single_meta_info_class = array(
		'.single_post .post-info > span:after',
		'.single-full-header .post-info > span:after',
		'.single_post .post-info > span.thecategory a:last-child:after',
		'.single-full-header .post-info > span.thecategory a:last-child:after',
	);
	$single_meta_info_font  = chronicle_get_settings( 'mts_single_meta_info_font' );
	$css['global'][ chronicle_implode( $single_meta_info_class ) ]['background-color'] = Chronicle_Sanitize::color( $single_meta_info_font['color'] );

	// Breadcrumb
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'breadcrumb_font' ) ) );
	$breadcrumb_class = array(
		'.breadcrumb-wrapper',
	);

	$css['global'][ chronicle_implode( $breadcrumb_class ) ] = Chronicle_Sanitize::background( chronicle_get_settings( 'breadcrumb_background' ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $breadcrumb_class ) ], Chronicle_Sanitize::margin( chronicle_get_settings( 'breadcrumb_margin' ) ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $breadcrumb_class ) ], Chronicle_Sanitize::padding( chronicle_get_settings( 'breadcrumb_padding' ) ) );

	$breadcrumb_border = Chronicle_Sanitize::border( chronicle_get_settings( 'breadcrumb_border' ) );
	$css['global'][ chronicle_implode( $breadcrumb_class ) ][ $breadcrumb_border ['direction'] ] = $breadcrumb_border ['value'];
	$breadcrumb_class = array(
		'.breadcrumb .separator',
	);
	$breadcrumb_font  = chronicle_get_settings( 'breadcrumb_font' );
	$css['global'][ chronicle_implode( $breadcrumb_class ) ]['background-color'] = Chronicle_Sanitize::color( $breadcrumb_font['color'] );

	// Tags.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'tags_font' ) ) );
	$tags_class = array(
		'.tags',
	);

	$css['global'][ chronicle_implode( $tags_class ) ] = Chronicle_Sanitize::background( chronicle_get_settings( 'tags_background' ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $tags_class ) ], Chronicle_Sanitize::margin( chronicle_get_settings( 'tags_margin' ) ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $tags_class ) ], Chronicle_Sanitize::padding( chronicle_get_settings( 'tags_padding' ) ) );

	// Related Posts.
	$related_class = array(
		'.related-posts',
	);
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'related_posts_meta_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'related_posts_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'related_posts_text_font' ) ) );
	$css['global'][ chronicle_implode( $related_class ) ] = Chronicle_Sanitize::background( chronicle_get_settings( 'related_posts_background' ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $related_class ) ], Chronicle_Sanitize::margin( chronicle_get_settings( 'related_posts_margin' ) ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $related_class ) ], Chronicle_Sanitize::padding( chronicle_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Chronicle_Sanitize::border( chronicle_get_settings( 'related_posts_border' ) );
	$css['global'][ chronicle_implode( $related_class ) ][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts article'] = Chronicle_Sanitize::background( chronicle_get_settings( 'related_article_background' ) );
	chronicle_merge_value( $css['global']['.related-posts article .wrapper'], Chronicle_Sanitize::padding( chronicle_get_settings( 'related_article_padding' ) ) );
	$related_meta_info_class = array(
		'.related-posts .post-info > span:after',
		'.related-posts .post-info > span.thecategory a:last-child:after',
	);
	$related_meta_info_font  = chronicle_get_settings( 'related_posts_meta_font' );
	$css['global'][ chronicle_implode( $related_meta_info_class ) ]['background-color'] = Chronicle_Sanitize::color( $related_meta_info_font['color'] );

	// Post FullHeader.
	chronicle_merge_value( $css['global']['.single-full-header'], Chronicle_Sanitize::padding( chronicle_get_settings( 'featured_image_padding' ) ) );
	chronicle_merge_value( $css['global']['.single-full-header'], Chronicle_Sanitize::margin( chronicle_get_settings( 'featured_image_margin' ) ) );

	// Subscribe Box.
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Chronicle_Sanitize::background( chronicle_get_settings( 'single_subscribe_background' ) );
	chronicle_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Chronicle_Sanitize::margin( chronicle_get_settings( 'single_subscribe_margin' ) ) );
	chronicle_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Chronicle_Sanitize::padding( chronicle_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Chronicle_Sanitize::size( chronicle_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe border.
	$subscribe_border = Chronicle_Sanitize::border( chronicle_get_settings( 'single_subscribe_border' ) );
	$css['global']['.single-subscribe .widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ chronicle_implode( $subscribe_input_class ) ]['height'] = Chronicle_Sanitize::size( chronicle_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Chronicle_Sanitize::size( chronicle_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['line-height'] = Chronicle_Sanitize::size( chronicle_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global'][ chronicle_implode( $subscribe_input_class ) ]['border-radius'] = Chronicle_Sanitize::size( chronicle_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = Chronicle_Sanitize::border( chronicle_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ chronicle_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Chronicle_Sanitize::color( chronicle_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Chronicle_Sanitize::size( chronicle_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Chronicle_Sanitize::border( chronicle_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	chronicle_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Chronicle_Sanitize::padding( chronicle_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Chronicle_Sanitize::background( chronicle_get_settings( 'authorbox_background' ) );
	chronicle_merge_value( $css['global']['.postauthor'], Chronicle_Sanitize::margin( chronicle_get_settings( 'authorbox_margin' ) ) );
	chronicle_merge_value( $css['global']['.postauthor'], Chronicle_Sanitize::padding( chronicle_get_settings( 'authorbox_padding' ) ) );
	$css['global']['.postauthor']['border-radius'] = Chronicle_Sanitize::size( chronicle_get_settings( 'authorbox_border_radius' ) . 'px' );
	// Border.
	//chronicle_merge_value( $css['global']['.postauthor'], Chronicle_Sanitize::border( chronicle_get_settings( 'authorbox_border' ) ) );
	$authorbox_border = Chronicle_Sanitize::border( chronicle_get_settings( 'authorbox_border' ) );
	$css['global']['.postauthor'][ $authorbox_border ['direction'] ] = $authorbox_border ['value'];
	// Author image.
	chronicle_merge_value( $css['global']['.postauthor img'], Chronicle_Sanitize::margin( chronicle_get_settings( 'single_author_image_margin' ) ) );
	$css['global']['.postauthor img']['border-radius'] = Chronicle_Sanitize::size( chronicle_get_settings( 'single_author_image_border_radius' ) . 'px' );
	// Author Social
	chronicle_merge_value( $css['global']['.author-social a'], Chronicle_Sanitize::margin( chronicle_get_settings( 'author_social_margin' ) ) );
	chronicle_merge_value( $css['global']['.author-social a'], Chronicle_Sanitize::padding( chronicle_get_settings( 'author_social_padding' ) ) );
	$css['global']['.author-social a'] ['background']       = Chronicle_Sanitize::color( chronicle_get_settings( 'author_social_background' ) );
	$css['global']['.author-social a:hover'] ['background'] = Chronicle_Sanitize::color( chronicle_get_settings( 'author_social_hover_background' ) );
	$css['global']['.author-social a']['color']             = Chronicle_Sanitize::color( chronicle_get_settings( 'author_social_color' ) );
	$css['global']['.author-social a:hover']['color']       = Chronicle_Sanitize::color( chronicle_get_settings( 'author_social_hover_color' ) );
	$css['global']['.author-social a']['border-radius']     = Chronicle_Sanitize::size( chronicle_get_settings( 'author_social_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = chronicle_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ chronicle_implode( $titles_class ) ] = Chronicle_Sanitize::background( chronicle_get_settings( 'single_title_background' ) );
	chronicle_merge_value( $css['global'][ chronicle_implode( $titles_class ) ], Chronicle_Sanitize::padding( chronicle_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Chronicle_Sanitize::border( chronicle_get_settings( 'single_title_border' ) );
	$css['global'][ chronicle_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ chronicle_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ chronicle_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ chronicle_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ chronicle_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ chronicle_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

	// Comments.
	// Margin and Padding.

	// Author Comment.
	$css['global']['#comments li.bypostauthor .comment-list']['background-color'] = Chronicle_Sanitize::color( chronicle_get_settings( 'author_comment_bg' ) );

	// Typography.
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'comments_title_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'comments_meta_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'comments_text_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'reply_font' ) ) );

}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_copyrights( &$css ) {

	// Copyrights
	chronicle_merge_value( $css['global']['.copyrights'], Chronicle_Sanitize::margin( chronicle_get_settings( 'mts_copyrights_margin' ) ) );
	chronicle_merge_value( $css['global']['.copyrights'], Chronicle_Sanitize::padding( chronicle_get_settings( 'mts_copyrights_padding' ) ) );
	chronicle_merge_value( $css['global']['..copyrights'], Chronicle_Sanitize::background( chronicle_get_settings( 'mts_copyrights_background' ) ) );
	$copyrights_border = Chronicle_Sanitize::border( chronicle_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];

}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_footer( &$css ) {

	// Footer.
	chronicle_merge_value( $css['global']['#site-footer'], Chronicle_Sanitize::margin( chronicle_get_settings( 'mts_top_footer_margin' ) ) );
	chronicle_merge_value( $css['global']['#site-footer'], Chronicle_Sanitize::padding( chronicle_get_settings( 'mts_top_footer_padding' ) ) );
	$css['global']['#site-footer:after']['background'] = Chronicle_Sanitize::color( chronicle_get_settings( 'footer_background_opacity' ) );

	$footer_meta_info_class = array(
		'#site-footer .post-info > span:after',
		'#site-footer .post-info > span.thecategory a:last-child:after',
	);
	$footer_meta_info_font  = chronicle_get_settings( 'top_footer_meta_font' );
	$css['global'][ chronicle_implode( $footer_meta_info_class ) ]['background-color'] = Chronicle_Sanitize::color( $footer_meta_info_font['color'] );

	// Subscribe Box.
	$css['global']['#site-footer .widget.wp_subscribe'] = Chronicle_Sanitize::background( chronicle_get_settings( 'footer_subscribe_widget_background' ) );
	chronicle_merge_value( $css['global']['#site-footer .widget.wp_subscribe'], Chronicle_Sanitize::padding( chronicle_get_settings( 'footer_subscribe_widget_padding' ) ) );
	$footer_subscribe_border = Chronicle_Sanitize::border( chronicle_get_settings( 'footer_subscribe_widget_border' ) );
	$css['global']['#site-footer .widget.wp_subscribe'][ $footer_subscribe_border ['direction'] ] = $footer_subscribe_border ['value'];
	// Subscribe Box Submit button.
	$css['global']['#site-footer .widget #wp-subscribe input.submit']['background'] = Chronicle_Sanitize::color( chronicle_get_settings( 'footer_subscribe_widget_submit_backgroud' ) );

}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_archive_post( &$css ) {

	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'archive_post_title_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'archive_post_excerpt_font' ) ) );
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'archive_meta_info_font' ) ) );

	/**
	 * Post Hover Settings
	 */
	chronicle_map_css_selectors( $css['global'], Chronicle_Sanitize::typography( chronicle_get_settings( 'archive_view_more_font' ) ) );
	$archive_view_more_class = array(
		'.archive .latestPost .view-more',
		'.search .latestPost .view-more',
		'.archive [class^="more-page"] .latestPost .view-more',
		'.search [class^="more-page"] .latestPost .view-more',
	);
	$css['global'][ chronicle_implode( $archive_view_more_class ) ]['background-color'] = Chronicle_Sanitize::color( chronicle_get_settings( 'archive_view_more_bg' ) );
	$archive_post_hover_class = array(
		'.archive .latestPost .post-hover:before',
		'.search .latestPost .post-hover:before',
		'.archive [class^="more-page"] .latestPost .post-hover:before',
		'.search [class^="more-page"] .latestPost .post-hover:before',
	);
	$css['global'][ chronicle_implode( $archive_post_hover_class ) ]['background-color'] = Chronicle_Sanitize::color( chronicle_get_settings( 'archive_post_overlay' ) );
	//Post Alignment
	$post_alignment       = chronicle_get_settings( 'archive_post_alignment' );
	$post_alignment_class = array(
		'.archive .latestPost',
		'.search .latestPost',
	);
	if ( 'center' === $post_alignment ) :
		$css['global'][ chronicle_implode( $post_alignment_class ) ]['text-align'] = 'center';
	endif;
	if ( 'right' === $post_alignment ) :
		$css['global'][ chronicle_implode( $post_alignment_class ) ]['text-align'] = 'right';
	endif;

	$archive_meta_info_class = array(
		'.archive .latestPost .post-info > span:after',
		'.search .latestPost .post-info > span:after',
		'.archive .latestPost .post-info > span.thecategory a:last-child:after',
		'.search .latestPost .post-info > span.thecategory a:last-child:after',
	);
	$archive_meta_info_font  = chronicle_get_settings( 'archive_meta_info_font' );
	$css['global'][ chronicle_implode( $archive_meta_info_class ) ]['background-color'] = Chronicle_Sanitize::color( $archive_meta_info_font['color'] );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function chronicle_misc_css( &$css ) {

	// Nav hover color position.
	$padding        = Chronicle_Sanitize::padding( chronicle_get_settings( 'header_padding' ) );
	$padding_bottom = (int) $padding['padding-bottom'];

	// Show Logo.
	$show_logo = chronicle_get_settings( 'hide_logo' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	$css['global']['#move-to-top']['background-color']       = Chronicle_Sanitize::color( chronicle_get_settings( 'top_button_background' ) );
	$css['global']['#move-to-top:hover']['background-color'] = Chronicle_Sanitize::color( chronicle_get_settings( 'top_button_background_hover' ) );

	// Border.
	$top_button_border = Chronicle_Sanitize::border( chronicle_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	chronicle_merge_value( $css['global']['#move-to-top'], Chronicle_Sanitize::padding( chronicle_get_settings( 'top_button_padding' ) ) );
	if ( 'floating' === chronicle_get_settings( 'bt_top_button_position' ) ) :
		$top_button_position = chronicle_get_settings( 'top_button_position' );
		foreach ( $top_button_position as $key => $position ) {
			$css['global']['#move-to-top'][ $key ] = $position;
		}
	endif;
	if ( 'bottom' === chronicle_get_settings( 'bt_top_button_position' ) ) :
		chronicle_merge_value( $css['global']['.move-to-top'], Chronicle_Sanitize::margin( chronicle_get_settings( 'top_bottom_button_margin' ) ) );
	endif;
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Chronicle_Sanitize::size( chronicle_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top svg path']['stroke']       = Chronicle_Sanitize::color( chronicle_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover svg path']['stroke'] = Chronicle_Sanitize::color( chronicle_get_settings( 'top_button_color_hover' ) );
	$css['global']['#move-to-top:hover']['border-color']    = Chronicle_Sanitize::color( chronicle_get_settings( 'top_button_background_hover' ) );

	// Full width Related Posts.
	if ( 'full' === chronicle_get_settings( 'related_posts_position' ) ) {
		$css['global']['.single .article']['margin-bottom'] = '0px';
	}

}
